@@ -1,12 +1,14 @@
-# Copyright (c) 2020 Tulir Asokan
+# Copyright (c) 2021 Tulir Asokan
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
-from typing import Optional, Type, Any
+from typing import Optional, Type
 from abc import ABC, abstractmethod
 import sys
 
+from aiohttp import web
+
 from mautrix.types import RoomID, UserID
 from mautrix.appservice import AppService, ASStateStore
 from mautrix.api import HTTPAPI
@@ -104,6 +106,7 @@ class Bridge(Program, ABC):
     def prepare_appservice(self) -> None:
         self.make_state_store()
         mb = 1024 ** 2
+        default_http_retry_count = self.config.get("homeserver.http_retry_count", None)
         self.az = AppService(server=self.config["homeserver.address"],
                              domain=self.config["homeserver.domain"],
                              verify_ssl=self.config["homeserver.verify_ssl"],
@@ -119,6 +122,7 @@ class Bridge(Program, ABC):
                              ephemeral_events=self.config["appservice.ephemeral_events"],
 
                              default_ua=f"{self.name}/{self.version} {HTTPAPI.default_ua}",
+                             default_http_retry_count=default_http_retry_count,
 
                              log="mau.as",
                              loop=self.loop,
@@ -130,6 +134,7 @@ class Bridge(Program, ABC):
                              aiohttp_params={
                                  "client_max_size": self.config["appservice.max_body_size"] * mb
                              })
+        self.az.app.router.add_post("/_matrix/app/com.beeper.bridge_state", self.get_bridge_state)
 
     def prepare_db(self) -> None:
         if not sql:
@@ -160,6 +165,22 @@ class Bridge(Program, ABC):
         if self.matrix.e2ee:
             await self.matrix.e2ee.stop()
 
+    async def get_bridge_state(self, req: web.Request) -> web.Response:
+        if not self.az._check_token(req):
+            return web.json_response({"error": "Invalid auth token"}, status=401)
+        try:
+            user = await self.get_user(UserID(req.url.query["user_id"]), create=False)
+        except KeyError:
+            user = None
+        if user is None:
+            return web.json_response({"error": "User not found"}, status=404)
+        try:
+            state = await user.get_bridge_state()
+        except NotImplementedError:
+            return web.json_response({"error": "Bridge status not implemented"}, status=501)
+        state.user_id = user.mxid
+        return web.json_response(state.fill().serialize())
+
     @abstractmethod
     async def get_user(self, user_id: UserID, create: bool = True) -> 'BaseUser':
         pass
