@@ -73,9 +73,8 @@ class SQLStateStore(StateStore):
         return [profile.user_id for profile
                 in UserProfile.all_in_room(room_id, not_suffix, not_prefix, not_id)]
 
-    async def set_members(self, room_id: RoomID, members: Dict[UserID, Member],
-                          joined_only: bool = False) -> None:
-        UserProfile.bulk_replace(room_id, members, joined_only=joined_only)
+    async def set_members(self, room_id: RoomID, members: Dict[UserID, Member]) -> None:
+        UserProfile.bulk_replace(room_id, members)
         self._get_room_state(room_id, create=True).edit(has_full_member_list=True)
         try:
             del self._profile_cache[room_id]
